@@ -247,10 +247,10 @@ class Loaf:
             raise Exception("No FROM specified.")
         # First fabricate the query.
         query = f"SELECT {select}"
-        query += f" FROM {parse(fromm)}" if fromm != "" else ""
-        query += f" WHERE {parse(where)}" if where != "" else ""
-        query += f" ORDER BY {parse(order)}" if order != "" else ""
-        query += f" LIMIT {parse(limit)}" if limit != "" else ""
+        query += f" FROM {fromm}" if fromm != "" else ""
+        query += f" WHERE {where}" if where != "" else ""
+        query += f" ORDER BY {order}" if order != "" else ""
+        query += f" LIMIT {limit}" if limit != "" else ""
         query += ";"
         # Execute the query.
         self.cursor.execute(query)
